@@ -1,4 +1,4 @@
-package Pcore::Chrome v0.14.0;
+package Pcore::Chrome v0.14.1;
 
 use Pcore -dist, -class, -res, -const;
 use Pcore::Chrome::Tab;
@@ -70,7 +70,7 @@ around new => sub ( $orig, $self, %args ) {
         '--disable-web-security',
         '--allow-running-insecure-content',
 
-        qq[--proxy-pac-url="http://$self->{_pac}->{listen}->{host_port}/"],
+        qq[--proxy-pac-url="http://$self->{_pac_server}->{listen}->{host_port}/"],
 
         # logging
         # '--disable-logging',
