@@ -42,6 +42,12 @@ sub new_tab ( $self, @args ) {
     return;
 }
 
+sub reload_pac ( $self ) {
+    $self->{chrome}->reload_pac;
+
+    return;
+}
+
 sub close ( $self ) {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms NamingConventions::ProhibitAmbiguousNames]
     return P->http->get("http://$self->{chrome}->{host}:$self->{chrome}->{port}/json/close/$self->{id}");
 }
